# This file was auto-generated by Fern from our API Definition.

import typing
from .agents_search_response_agents_item_tool_exec_environment_variables_item import (
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItem,
)

AgentsSearchResponseAgentsItemToolExecEnvironmentVariables = typing.Union[
    typing.List[AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItem], typing.Optional[typing.Any]
]
