# This file was auto-generated by Fern from our API Definition.

import typing
from .response_format_text import ResponseFormatText
from .response_format_json_object import ResponseFormatJsonObject
from .response_format_json_schema import ResponseFormatJsonSchema

CompletionCreateParamsNonStreamingResponseFormat = typing.Union[
    ResponseFormatText, ResponseFormatJsonObject, ResponseFormatJsonSchema
]
