# This file was auto-generated by Fern from our API Definition.

import typing
from .templates_create_agents_from_template_response_agents_item_tool_exec_environment_variables_item_last_updated_by_id_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedByIdItem,
)

TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedById = typing.Union[
    str,
    typing.Optional[str],
    typing.List[
        typing.Optional[
            TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedByIdItem
        ]
    ],
    typing.Optional[typing.Any],
]
