# This file was auto-generated by Fern from our API Definition.

import typing
from .templates_create_agents_from_template_response_agents_item_sources_item_embedding_config_handle_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigHandleItem,
)

TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigHandle = typing.Union[
    str,
    typing.Optional[str],
    typing.List[
        typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigHandleItem]
    ],
    typing.Optional[typing.Any],
]
