# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
import typing
from .templates_create_agents_from_template_response_agents_item_created_by_id import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemCreatedById,
)
from .templates_create_agents_from_template_response_agents_item_last_updated_by_id import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLastUpdatedById,
)
from .templates_create_agents_from_template_response_agents_item_created_at import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemCreatedAt,
)
from .templates_create_agents_from_template_response_agents_item_updated_at import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemUpdatedAt,
)
from .templates_create_agents_from_template_response_agents_item_tool_rules import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRules,
)
from .templates_create_agents_from_template_response_agents_item_message_ids import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMessageIds,
)
from .templates_create_agents_from_template_response_agents_item_agent_type import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemAgentType,
)
from .templates_create_agents_from_template_response_agents_item_llm_config import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfig,
)
from .templates_create_agents_from_template_response_agents_item_embedding_config import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfig,
)
from .templates_create_agents_from_template_response_agents_item_organization_id import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemOrganizationId,
)
from .templates_create_agents_from_template_response_agents_item_description import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemDescription,
)
from .templates_create_agents_from_template_response_agents_item_metadata import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMetadata,
)
from .templates_create_agents_from_template_response_agents_item_memory import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemory,
)
from .templates_create_agents_from_template_response_agents_item_tools_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItem,
)
from .templates_create_agents_from_template_response_agents_item_sources_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItem,
)
from .templates_create_agents_from_template_response_agents_item_tool_exec_environment_variables import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariables,
)
from .templates_create_agents_from_template_response_agents_item_project_id import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemProjectId,
)
from .templates_create_agents_from_template_response_agents_item_template_id import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemTemplateId,
)
from .templates_create_agents_from_template_response_agents_item_base_template_id import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemBaseTemplateId,
)
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class TemplatesCreateAgentsFromTemplateResponseAgentsItem(UncheckedBaseModel):
    created_by_id: typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemCreatedById] = None
    last_updated_by_id: typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemLastUpdatedById] = None
    created_at: typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemCreatedAt] = None
    updated_at: typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemUpdatedAt] = None
    id: str
    name: str
    tool_rules: typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRules] = None
    message_ids: typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemMessageIds] = None
    system: str
    agent_type: TemplatesCreateAgentsFromTemplateResponseAgentsItemAgentType
    llm_config: TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfig
    embedding_config: TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfig
    organization_id: typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemOrganizationId] = None
    description: typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemDescription] = None
    metadata: typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemMetadata] = None
    memory: TemplatesCreateAgentsFromTemplateResponseAgentsItemMemory
    tools: typing.List[TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItem]
    sources: typing.List[TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItem]
    tags: typing.List[str]
    tool_exec_environment_variables: typing.Optional[
        TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariables
    ] = None
    project_id: typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemProjectId] = None
    template_id: typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemTemplateId] = None
    base_template_id: typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemBaseTemplateId] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
