# This file was auto-generated by Fern from our API Definition.

import typing
from .chat_completion_user_message_param_content_item import ChatCompletionUserMessageParamContentItem

ChatCompletionUserMessageParamContent = typing.Union[str, typing.List[ChatCompletionUserMessageParamContentItem]]
