# This file was auto-generated by Fern from our API Definition.

from .agents_search_request_search_item import AgentsSearchRequestSearchItem
from .agents_search_request_search_item_field import AgentsSearchRequestSearchItemField
from .agents_search_request_search_item_one import AgentsSearchRequestSearchItemOne
from .agents_search_request_search_item_one_operator import AgentsSearchRequestSearchItemOneOperator
from .agents_search_request_search_item_zero import AgentsSearchRequestSearchItemZero
from .agents_search_response import AgentsSearchResponse
from .agents_search_response_agents_item import AgentsSearchResponseAgentsItem
from .agents_search_response_agents_item_agent_type import AgentsSearchResponseAgentsItemAgentType
from .agents_search_response_agents_item_base_template_id import AgentsSearchResponseAgentsItemBaseTemplateId
from .agents_search_response_agents_item_base_template_id_item import AgentsSearchResponseAgentsItemBaseTemplateIdItem
from .agents_search_response_agents_item_created_at import AgentsSearchResponseAgentsItemCreatedAt
from .agents_search_response_agents_item_created_at_item import AgentsSearchResponseAgentsItemCreatedAtItem
from .agents_search_response_agents_item_created_by_id import AgentsSearchResponseAgentsItemCreatedById
from .agents_search_response_agents_item_created_by_id_item import AgentsSearchResponseAgentsItemCreatedByIdItem
from .agents_search_response_agents_item_description import AgentsSearchResponseAgentsItemDescription
from .agents_search_response_agents_item_description_item import AgentsSearchResponseAgentsItemDescriptionItem
from .agents_search_response_agents_item_embedding_config import AgentsSearchResponseAgentsItemEmbeddingConfig
from .agents_search_response_agents_item_embedding_config_azure_deployment import (
    AgentsSearchResponseAgentsItemEmbeddingConfigAzureDeployment,
)
from .agents_search_response_agents_item_embedding_config_azure_deployment_item import (
    AgentsSearchResponseAgentsItemEmbeddingConfigAzureDeploymentItem,
)
from .agents_search_response_agents_item_embedding_config_azure_endpoint import (
    AgentsSearchResponseAgentsItemEmbeddingConfigAzureEndpoint,
)
from .agents_search_response_agents_item_embedding_config_azure_endpoint_item import (
    AgentsSearchResponseAgentsItemEmbeddingConfigAzureEndpointItem,
)
from .agents_search_response_agents_item_embedding_config_azure_version import (
    AgentsSearchResponseAgentsItemEmbeddingConfigAzureVersion,
)
from .agents_search_response_agents_item_embedding_config_azure_version_item import (
    AgentsSearchResponseAgentsItemEmbeddingConfigAzureVersionItem,
)
from .agents_search_response_agents_item_embedding_config_embedding_chunk_size import (
    AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingChunkSize,
)
from .agents_search_response_agents_item_embedding_config_embedding_chunk_size_item import (
    AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingChunkSizeItem,
)
from .agents_search_response_agents_item_embedding_config_embedding_endpoint import (
    AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingEndpoint,
)
from .agents_search_response_agents_item_embedding_config_embedding_endpoint_item import (
    AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingEndpointItem,
)
from .agents_search_response_agents_item_embedding_config_embedding_endpoint_type import (
    AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingEndpointType,
)
from .agents_search_response_agents_item_embedding_config_handle import (
    AgentsSearchResponseAgentsItemEmbeddingConfigHandle,
)
from .agents_search_response_agents_item_embedding_config_handle_item import (
    AgentsSearchResponseAgentsItemEmbeddingConfigHandleItem,
)
from .agents_search_response_agents_item_last_updated_by_id import AgentsSearchResponseAgentsItemLastUpdatedById
from .agents_search_response_agents_item_last_updated_by_id_item import (
    AgentsSearchResponseAgentsItemLastUpdatedByIdItem,
)
from .agents_search_response_agents_item_llm_config import AgentsSearchResponseAgentsItemLlmConfig
from .agents_search_response_agents_item_llm_config_handle import AgentsSearchResponseAgentsItemLlmConfigHandle
from .agents_search_response_agents_item_llm_config_handle_item import AgentsSearchResponseAgentsItemLlmConfigHandleItem
from .agents_search_response_agents_item_llm_config_model_endpoint import (
    AgentsSearchResponseAgentsItemLlmConfigModelEndpoint,
)
from .agents_search_response_agents_item_llm_config_model_endpoint_item import (
    AgentsSearchResponseAgentsItemLlmConfigModelEndpointItem,
)
from .agents_search_response_agents_item_llm_config_model_endpoint_type import (
    AgentsSearchResponseAgentsItemLlmConfigModelEndpointType,
)
from .agents_search_response_agents_item_llm_config_model_wrapper import (
    AgentsSearchResponseAgentsItemLlmConfigModelWrapper,
)
from .agents_search_response_agents_item_llm_config_model_wrapper_item import (
    AgentsSearchResponseAgentsItemLlmConfigModelWrapperItem,
)
from .agents_search_response_agents_item_llm_config_put_inner_thoughts_in_kwargs import (
    AgentsSearchResponseAgentsItemLlmConfigPutInnerThoughtsInKwargs,
)
from .agents_search_response_agents_item_llm_config_put_inner_thoughts_in_kwargs_item import (
    AgentsSearchResponseAgentsItemLlmConfigPutInnerThoughtsInKwargsItem,
)
from .agents_search_response_agents_item_llm_config_temperature import (
    AgentsSearchResponseAgentsItemLlmConfigTemperature,
)
from .agents_search_response_agents_item_memory import AgentsSearchResponseAgentsItemMemory
from .agents_search_response_agents_item_memory_blocks_item import AgentsSearchResponseAgentsItemMemoryBlocksItem
from .agents_search_response_agents_item_memory_blocks_item_created_by_id import (
    AgentsSearchResponseAgentsItemMemoryBlocksItemCreatedById,
)
from .agents_search_response_agents_item_memory_blocks_item_created_by_id_item import (
    AgentsSearchResponseAgentsItemMemoryBlocksItemCreatedByIdItem,
)
from .agents_search_response_agents_item_memory_blocks_item_description import (
    AgentsSearchResponseAgentsItemMemoryBlocksItemDescription,
)
from .agents_search_response_agents_item_memory_blocks_item_description_item import (
    AgentsSearchResponseAgentsItemMemoryBlocksItemDescriptionItem,
)
from .agents_search_response_agents_item_memory_blocks_item_id import AgentsSearchResponseAgentsItemMemoryBlocksItemId
from .agents_search_response_agents_item_memory_blocks_item_is_template import (
    AgentsSearchResponseAgentsItemMemoryBlocksItemIsTemplate,
)
from .agents_search_response_agents_item_memory_blocks_item_label import (
    AgentsSearchResponseAgentsItemMemoryBlocksItemLabel,
)
from .agents_search_response_agents_item_memory_blocks_item_label_item import (
    AgentsSearchResponseAgentsItemMemoryBlocksItemLabelItem,
)
from .agents_search_response_agents_item_memory_blocks_item_last_updated_by_id import (
    AgentsSearchResponseAgentsItemMemoryBlocksItemLastUpdatedById,
)
from .agents_search_response_agents_item_memory_blocks_item_last_updated_by_id_item import (
    AgentsSearchResponseAgentsItemMemoryBlocksItemLastUpdatedByIdItem,
)
from .agents_search_response_agents_item_memory_blocks_item_limit import (
    AgentsSearchResponseAgentsItemMemoryBlocksItemLimit,
)
from .agents_search_response_agents_item_memory_blocks_item_metadata import (
    AgentsSearchResponseAgentsItemMemoryBlocksItemMetadata,
)
from .agents_search_response_agents_item_memory_blocks_item_metadata_item import (
    AgentsSearchResponseAgentsItemMemoryBlocksItemMetadataItem,
)
from .agents_search_response_agents_item_memory_blocks_item_name import (
    AgentsSearchResponseAgentsItemMemoryBlocksItemName,
)
from .agents_search_response_agents_item_memory_blocks_item_name_item import (
    AgentsSearchResponseAgentsItemMemoryBlocksItemNameItem,
)
from .agents_search_response_agents_item_memory_blocks_item_organization_id import (
    AgentsSearchResponseAgentsItemMemoryBlocksItemOrganizationId,
)
from .agents_search_response_agents_item_memory_blocks_item_organization_id_item import (
    AgentsSearchResponseAgentsItemMemoryBlocksItemOrganizationIdItem,
)
from .agents_search_response_agents_item_memory_prompt_template import (
    AgentsSearchResponseAgentsItemMemoryPromptTemplate,
)
from .agents_search_response_agents_item_message_ids import AgentsSearchResponseAgentsItemMessageIds
from .agents_search_response_agents_item_message_ids_item import AgentsSearchResponseAgentsItemMessageIdsItem
from .agents_search_response_agents_item_metadata import AgentsSearchResponseAgentsItemMetadata
from .agents_search_response_agents_item_metadata_item import AgentsSearchResponseAgentsItemMetadataItem
from .agents_search_response_agents_item_organization_id import AgentsSearchResponseAgentsItemOrganizationId
from .agents_search_response_agents_item_organization_id_item import AgentsSearchResponseAgentsItemOrganizationIdItem
from .agents_search_response_agents_item_project_id import AgentsSearchResponseAgentsItemProjectId
from .agents_search_response_agents_item_project_id_item import AgentsSearchResponseAgentsItemProjectIdItem
from .agents_search_response_agents_item_sources_item import AgentsSearchResponseAgentsItemSourcesItem
from .agents_search_response_agents_item_sources_item_created_at import (
    AgentsSearchResponseAgentsItemSourcesItemCreatedAt,
)
from .agents_search_response_agents_item_sources_item_created_at_item import (
    AgentsSearchResponseAgentsItemSourcesItemCreatedAtItem,
)
from .agents_search_response_agents_item_sources_item_created_by_id import (
    AgentsSearchResponseAgentsItemSourcesItemCreatedById,
)
from .agents_search_response_agents_item_sources_item_created_by_id_item import (
    AgentsSearchResponseAgentsItemSourcesItemCreatedByIdItem,
)
from .agents_search_response_agents_item_sources_item_description import (
    AgentsSearchResponseAgentsItemSourcesItemDescription,
)
from .agents_search_response_agents_item_sources_item_description_item import (
    AgentsSearchResponseAgentsItemSourcesItemDescriptionItem,
)
from .agents_search_response_agents_item_sources_item_embedding_config import (
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfig,
)
from .agents_search_response_agents_item_sources_item_embedding_config_azure_deployment import (
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureDeployment,
)
from .agents_search_response_agents_item_sources_item_embedding_config_azure_deployment_item import (
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureDeploymentItem,
)
from .agents_search_response_agents_item_sources_item_embedding_config_azure_endpoint import (
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpoint,
)
from .agents_search_response_agents_item_sources_item_embedding_config_azure_endpoint_item import (
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpointItem,
)
from .agents_search_response_agents_item_sources_item_embedding_config_azure_version import (
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureVersion,
)
from .agents_search_response_agents_item_sources_item_embedding_config_azure_version_item import (
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureVersionItem,
)
from .agents_search_response_agents_item_sources_item_embedding_config_embedding_chunk_size import (
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSize,
)
from .agents_search_response_agents_item_sources_item_embedding_config_embedding_chunk_size_item import (
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSizeItem,
)
from .agents_search_response_agents_item_sources_item_embedding_config_embedding_endpoint import (
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpoint,
)
from .agents_search_response_agents_item_sources_item_embedding_config_embedding_endpoint_item import (
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointItem,
)
from .agents_search_response_agents_item_sources_item_embedding_config_embedding_endpoint_type import (
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointType,
)
from .agents_search_response_agents_item_sources_item_embedding_config_handle import (
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigHandle,
)
from .agents_search_response_agents_item_sources_item_embedding_config_handle_item import (
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigHandleItem,
)
from .agents_search_response_agents_item_sources_item_id import AgentsSearchResponseAgentsItemSourcesItemId
from .agents_search_response_agents_item_sources_item_last_updated_by_id import (
    AgentsSearchResponseAgentsItemSourcesItemLastUpdatedById,
)
from .agents_search_response_agents_item_sources_item_last_updated_by_id_item import (
    AgentsSearchResponseAgentsItemSourcesItemLastUpdatedByIdItem,
)
from .agents_search_response_agents_item_sources_item_metadata import AgentsSearchResponseAgentsItemSourcesItemMetadata
from .agents_search_response_agents_item_sources_item_metadata_item import (
    AgentsSearchResponseAgentsItemSourcesItemMetadataItem,
)
from .agents_search_response_agents_item_sources_item_organization_id import (
    AgentsSearchResponseAgentsItemSourcesItemOrganizationId,
)
from .agents_search_response_agents_item_sources_item_organization_id_item import (
    AgentsSearchResponseAgentsItemSourcesItemOrganizationIdItem,
)
from .agents_search_response_agents_item_sources_item_updated_at import (
    AgentsSearchResponseAgentsItemSourcesItemUpdatedAt,
)
from .agents_search_response_agents_item_sources_item_updated_at_item import (
    AgentsSearchResponseAgentsItemSourcesItemUpdatedAtItem,
)
from .agents_search_response_agents_item_template_id import AgentsSearchResponseAgentsItemTemplateId
from .agents_search_response_agents_item_template_id_item import AgentsSearchResponseAgentsItemTemplateIdItem
from .agents_search_response_agents_item_tool_exec_environment_variables import (
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariables,
)
from .agents_search_response_agents_item_tool_exec_environment_variables_item import (
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItem,
)
from .agents_search_response_agents_item_tool_exec_environment_variables_item_created_at import (
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAt,
)
from .agents_search_response_agents_item_tool_exec_environment_variables_item_created_at_item import (
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAtItem,
)
from .agents_search_response_agents_item_tool_exec_environment_variables_item_created_by_id import (
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedById,
)
from .agents_search_response_agents_item_tool_exec_environment_variables_item_created_by_id_item import (
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedByIdItem,
)
from .agents_search_response_agents_item_tool_exec_environment_variables_item_description import (
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemDescription,
)
from .agents_search_response_agents_item_tool_exec_environment_variables_item_description_item import (
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemDescriptionItem,
)
from .agents_search_response_agents_item_tool_exec_environment_variables_item_id import (
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemId,
)
from .agents_search_response_agents_item_tool_exec_environment_variables_item_last_updated_by_id import (
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedById,
)
from .agents_search_response_agents_item_tool_exec_environment_variables_item_last_updated_by_id_item import (
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedByIdItem,
)
from .agents_search_response_agents_item_tool_exec_environment_variables_item_organization_id import (
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationId,
)
from .agents_search_response_agents_item_tool_exec_environment_variables_item_organization_id_item import (
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationIdItem,
)
from .agents_search_response_agents_item_tool_exec_environment_variables_item_updated_at import (
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAt,
)
from .agents_search_response_agents_item_tool_exec_environment_variables_item_updated_at_item import (
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAtItem,
)
from .agents_search_response_agents_item_tool_rules import AgentsSearchResponseAgentsItemToolRules
from .agents_search_response_agents_item_tool_rules_item import AgentsSearchResponseAgentsItemToolRulesItem
from .agents_search_response_agents_item_tool_rules_item_child_output_mapping import (
    AgentsSearchResponseAgentsItemToolRulesItemChildOutputMapping,
)
from .agents_search_response_agents_item_tool_rules_item_child_output_mapping_default_child import (
    AgentsSearchResponseAgentsItemToolRulesItemChildOutputMappingDefaultChild,
)
from .agents_search_response_agents_item_tool_rules_item_child_output_mapping_default_child_item import (
    AgentsSearchResponseAgentsItemToolRulesItemChildOutputMappingDefaultChildItem,
)
from .agents_search_response_agents_item_tool_rules_item_child_output_mapping_require_output_mapping import (
    AgentsSearchResponseAgentsItemToolRulesItemChildOutputMappingRequireOutputMapping,
)
from .agents_search_response_agents_item_tool_rules_item_child_output_mapping_type import (
    AgentsSearchResponseAgentsItemToolRulesItemChildOutputMappingType,
)
from .agents_search_response_agents_item_tool_rules_item_children import (
    AgentsSearchResponseAgentsItemToolRulesItemChildren,
)
from .agents_search_response_agents_item_tool_rules_item_children_type import (
    AgentsSearchResponseAgentsItemToolRulesItemChildrenType,
)
from .agents_search_response_agents_item_tool_rules_item_item import AgentsSearchResponseAgentsItemToolRulesItemItem
from .agents_search_response_agents_item_tool_rules_item_item_child_output_mapping import (
    AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMapping,
)
from .agents_search_response_agents_item_tool_rules_item_item_child_output_mapping_default_child import (
    AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChild,
)
from .agents_search_response_agents_item_tool_rules_item_item_child_output_mapping_default_child_item import (
    AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChildItem,
)
from .agents_search_response_agents_item_tool_rules_item_item_child_output_mapping_require_output_mapping import (
    AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMappingRequireOutputMapping,
)
from .agents_search_response_agents_item_tool_rules_item_item_child_output_mapping_type import (
    AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMappingType,
)
from .agents_search_response_agents_item_tool_rules_item_item_children import (
    AgentsSearchResponseAgentsItemToolRulesItemItemChildren,
)
from .agents_search_response_agents_item_tool_rules_item_item_children_type import (
    AgentsSearchResponseAgentsItemToolRulesItemItemChildrenType,
)
from .agents_search_response_agents_item_tool_rules_item_item_one import (
    AgentsSearchResponseAgentsItemToolRulesItemItemOne,
)
from .agents_search_response_agents_item_tool_rules_item_item_one_type import (
    AgentsSearchResponseAgentsItemToolRulesItemItemOneType,
)
from .agents_search_response_agents_item_tool_rules_item_item_two import (
    AgentsSearchResponseAgentsItemToolRulesItemItemTwo,
)
from .agents_search_response_agents_item_tool_rules_item_item_two_type import (
    AgentsSearchResponseAgentsItemToolRulesItemItemTwoType,
)
from .agents_search_response_agents_item_tool_rules_item_one import AgentsSearchResponseAgentsItemToolRulesItemOne
from .agents_search_response_agents_item_tool_rules_item_one_type import (
    AgentsSearchResponseAgentsItemToolRulesItemOneType,
)
from .agents_search_response_agents_item_tool_rules_item_two import AgentsSearchResponseAgentsItemToolRulesItemTwo
from .agents_search_response_agents_item_tool_rules_item_two_type import (
    AgentsSearchResponseAgentsItemToolRulesItemTwoType,
)
from .agents_search_response_agents_item_tools_item import AgentsSearchResponseAgentsItemToolsItem
from .agents_search_response_agents_item_tools_item_created_by_id import (
    AgentsSearchResponseAgentsItemToolsItemCreatedById,
)
from .agents_search_response_agents_item_tools_item_created_by_id_item import (
    AgentsSearchResponseAgentsItemToolsItemCreatedByIdItem,
)
from .agents_search_response_agents_item_tools_item_description import (
    AgentsSearchResponseAgentsItemToolsItemDescription,
)
from .agents_search_response_agents_item_tools_item_description_item import (
    AgentsSearchResponseAgentsItemToolsItemDescriptionItem,
)
from .agents_search_response_agents_item_tools_item_json_schema import AgentsSearchResponseAgentsItemToolsItemJsonSchema
from .agents_search_response_agents_item_tools_item_json_schema_item import (
    AgentsSearchResponseAgentsItemToolsItemJsonSchemaItem,
)
from .agents_search_response_agents_item_tools_item_last_updated_by_id import (
    AgentsSearchResponseAgentsItemToolsItemLastUpdatedById,
)
from .agents_search_response_agents_item_tools_item_last_updated_by_id_item import (
    AgentsSearchResponseAgentsItemToolsItemLastUpdatedByIdItem,
)
from .agents_search_response_agents_item_tools_item_name import AgentsSearchResponseAgentsItemToolsItemName
from .agents_search_response_agents_item_tools_item_name_item import AgentsSearchResponseAgentsItemToolsItemNameItem
from .agents_search_response_agents_item_tools_item_organization_id import (
    AgentsSearchResponseAgentsItemToolsItemOrganizationId,
)
from .agents_search_response_agents_item_tools_item_organization_id_item import (
    AgentsSearchResponseAgentsItemToolsItemOrganizationIdItem,
)
from .agents_search_response_agents_item_tools_item_source_code import AgentsSearchResponseAgentsItemToolsItemSourceCode
from .agents_search_response_agents_item_tools_item_source_code_item import (
    AgentsSearchResponseAgentsItemToolsItemSourceCodeItem,
)
from .agents_search_response_agents_item_tools_item_source_type import AgentsSearchResponseAgentsItemToolsItemSourceType
from .agents_search_response_agents_item_tools_item_source_type_item import (
    AgentsSearchResponseAgentsItemToolsItemSourceTypeItem,
)
from .agents_search_response_agents_item_tools_item_tool_type import AgentsSearchResponseAgentsItemToolsItemToolType
from .agents_search_response_agents_item_updated_at import AgentsSearchResponseAgentsItemUpdatedAt
from .agents_search_response_agents_item_updated_at_item import AgentsSearchResponseAgentsItemUpdatedAtItem
from .create_agent_request_tool_rules_item import CreateAgentRequestToolRulesItem
from .update_agent_tool_rules_item import UpdateAgentToolRulesItem

__all__ = [
    "AgentsSearchRequestSearchItem",
    "AgentsSearchRequestSearchItemField",
    "AgentsSearchRequestSearchItemOne",
    "AgentsSearchRequestSearchItemOneOperator",
    "AgentsSearchRequestSearchItemZero",
    "AgentsSearchResponse",
    "AgentsSearchResponseAgentsItem",
    "AgentsSearchResponseAgentsItemAgentType",
    "AgentsSearchResponseAgentsItemBaseTemplateId",
    "AgentsSearchResponseAgentsItemBaseTemplateIdItem",
    "AgentsSearchResponseAgentsItemCreatedAt",
    "AgentsSearchResponseAgentsItemCreatedAtItem",
    "AgentsSearchResponseAgentsItemCreatedById",
    "AgentsSearchResponseAgentsItemCreatedByIdItem",
    "AgentsSearchResponseAgentsItemDescription",
    "AgentsSearchResponseAgentsItemDescriptionItem",
    "AgentsSearchResponseAgentsItemEmbeddingConfig",
    "AgentsSearchResponseAgentsItemEmbeddingConfigAzureDeployment",
    "AgentsSearchResponseAgentsItemEmbeddingConfigAzureDeploymentItem",
    "AgentsSearchResponseAgentsItemEmbeddingConfigAzureEndpoint",
    "AgentsSearchResponseAgentsItemEmbeddingConfigAzureEndpointItem",
    "AgentsSearchResponseAgentsItemEmbeddingConfigAzureVersion",
    "AgentsSearchResponseAgentsItemEmbeddingConfigAzureVersionItem",
    "AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingChunkSize",
    "AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingChunkSizeItem",
    "AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingEndpoint",
    "AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingEndpointItem",
    "AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingEndpointType",
    "AgentsSearchResponseAgentsItemEmbeddingConfigHandle",
    "AgentsSearchResponseAgentsItemEmbeddingConfigHandleItem",
    "AgentsSearchResponseAgentsItemLastUpdatedById",
    "AgentsSearchResponseAgentsItemLastUpdatedByIdItem",
    "AgentsSearchResponseAgentsItemLlmConfig",
    "AgentsSearchResponseAgentsItemLlmConfigHandle",
    "AgentsSearchResponseAgentsItemLlmConfigHandleItem",
    "AgentsSearchResponseAgentsItemLlmConfigModelEndpoint",
    "AgentsSearchResponseAgentsItemLlmConfigModelEndpointItem",
    "AgentsSearchResponseAgentsItemLlmConfigModelEndpointType",
    "AgentsSearchResponseAgentsItemLlmConfigModelWrapper",
    "AgentsSearchResponseAgentsItemLlmConfigModelWrapperItem",
    "AgentsSearchResponseAgentsItemLlmConfigPutInnerThoughtsInKwargs",
    "AgentsSearchResponseAgentsItemLlmConfigPutInnerThoughtsInKwargsItem",
    "AgentsSearchResponseAgentsItemLlmConfigTemperature",
    "AgentsSearchResponseAgentsItemMemory",
    "AgentsSearchResponseAgentsItemMemoryBlocksItem",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemCreatedById",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemCreatedByIdItem",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemDescription",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemDescriptionItem",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemId",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemIsTemplate",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemLabel",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemLabelItem",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemLastUpdatedById",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemLastUpdatedByIdItem",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemLimit",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemMetadata",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemMetadataItem",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemName",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemNameItem",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemOrganizationId",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemOrganizationIdItem",
    "AgentsSearchResponseAgentsItemMemoryPromptTemplate",
    "AgentsSearchResponseAgentsItemMessageIds",
    "AgentsSearchResponseAgentsItemMessageIdsItem",
    "AgentsSearchResponseAgentsItemMetadata",
    "AgentsSearchResponseAgentsItemMetadataItem",
    "AgentsSearchResponseAgentsItemOrganizationId",
    "AgentsSearchResponseAgentsItemOrganizationIdItem",
    "AgentsSearchResponseAgentsItemProjectId",
    "AgentsSearchResponseAgentsItemProjectIdItem",
    "AgentsSearchResponseAgentsItemSourcesItem",
    "AgentsSearchResponseAgentsItemSourcesItemCreatedAt",
    "AgentsSearchResponseAgentsItemSourcesItemCreatedAtItem",
    "AgentsSearchResponseAgentsItemSourcesItemCreatedById",
    "AgentsSearchResponseAgentsItemSourcesItemCreatedByIdItem",
    "AgentsSearchResponseAgentsItemSourcesItemDescription",
    "AgentsSearchResponseAgentsItemSourcesItemDescriptionItem",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfig",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureDeployment",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureDeploymentItem",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpoint",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpointItem",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureVersion",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureVersionItem",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSize",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSizeItem",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpoint",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointItem",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointType",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigHandle",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigHandleItem",
    "AgentsSearchResponseAgentsItemSourcesItemId",
    "AgentsSearchResponseAgentsItemSourcesItemLastUpdatedById",
    "AgentsSearchResponseAgentsItemSourcesItemLastUpdatedByIdItem",
    "AgentsSearchResponseAgentsItemSourcesItemMetadata",
    "AgentsSearchResponseAgentsItemSourcesItemMetadataItem",
    "AgentsSearchResponseAgentsItemSourcesItemOrganizationId",
    "AgentsSearchResponseAgentsItemSourcesItemOrganizationIdItem",
    "AgentsSearchResponseAgentsItemSourcesItemUpdatedAt",
    "AgentsSearchResponseAgentsItemSourcesItemUpdatedAtItem",
    "AgentsSearchResponseAgentsItemTemplateId",
    "AgentsSearchResponseAgentsItemTemplateIdItem",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariables",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItem",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAt",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAtItem",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedById",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedByIdItem",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemDescription",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemDescriptionItem",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemId",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedById",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedByIdItem",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationId",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationIdItem",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAt",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAtItem",
    "AgentsSearchResponseAgentsItemToolRules",
    "AgentsSearchResponseAgentsItemToolRulesItem",
    "AgentsSearchResponseAgentsItemToolRulesItemChildOutputMapping",
    "AgentsSearchResponseAgentsItemToolRulesItemChildOutputMappingDefaultChild",
    "AgentsSearchResponseAgentsItemToolRulesItemChildOutputMappingDefaultChildItem",
    "AgentsSearchResponseAgentsItemToolRulesItemChildOutputMappingRequireOutputMapping",
    "AgentsSearchResponseAgentsItemToolRulesItemChildOutputMappingType",
    "AgentsSearchResponseAgentsItemToolRulesItemChildren",
    "AgentsSearchResponseAgentsItemToolRulesItemChildrenType",
    "AgentsSearchResponseAgentsItemToolRulesItemItem",
    "AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMapping",
    "AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChild",
    "AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChildItem",
    "AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMappingRequireOutputMapping",
    "AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMappingType",
    "AgentsSearchResponseAgentsItemToolRulesItemItemChildren",
    "AgentsSearchResponseAgentsItemToolRulesItemItemChildrenType",
    "AgentsSearchResponseAgentsItemToolRulesItemItemOne",
    "AgentsSearchResponseAgentsItemToolRulesItemItemOneType",
    "AgentsSearchResponseAgentsItemToolRulesItemItemTwo",
    "AgentsSearchResponseAgentsItemToolRulesItemItemTwoType",
    "AgentsSearchResponseAgentsItemToolRulesItemOne",
    "AgentsSearchResponseAgentsItemToolRulesItemOneType",
    "AgentsSearchResponseAgentsItemToolRulesItemTwo",
    "AgentsSearchResponseAgentsItemToolRulesItemTwoType",
    "AgentsSearchResponseAgentsItemToolsItem",
    "AgentsSearchResponseAgentsItemToolsItemCreatedById",
    "AgentsSearchResponseAgentsItemToolsItemCreatedByIdItem",
    "AgentsSearchResponseAgentsItemToolsItemDescription",
    "AgentsSearchResponseAgentsItemToolsItemDescriptionItem",
    "AgentsSearchResponseAgentsItemToolsItemJsonSchema",
    "AgentsSearchResponseAgentsItemToolsItemJsonSchemaItem",
    "AgentsSearchResponseAgentsItemToolsItemLastUpdatedById",
    "AgentsSearchResponseAgentsItemToolsItemLastUpdatedByIdItem",
    "AgentsSearchResponseAgentsItemToolsItemName",
    "AgentsSearchResponseAgentsItemToolsItemNameItem",
    "AgentsSearchResponseAgentsItemToolsItemOrganizationId",
    "AgentsSearchResponseAgentsItemToolsItemOrganizationIdItem",
    "AgentsSearchResponseAgentsItemToolsItemSourceCode",
    "AgentsSearchResponseAgentsItemToolsItemSourceCodeItem",
    "AgentsSearchResponseAgentsItemToolsItemSourceType",
    "AgentsSearchResponseAgentsItemToolsItemSourceTypeItem",
    "AgentsSearchResponseAgentsItemToolsItemToolType",
    "AgentsSearchResponseAgentsItemUpdatedAt",
    "AgentsSearchResponseAgentsItemUpdatedAtItem",
    "CreateAgentRequestToolRulesItem",
    "UpdateAgentToolRulesItem",
]
