# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
import typing
from .agents_search_response_agents_item_tool_exec_environment_variables_item_created_by_id import (
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedById,
)
from .agents_search_response_agents_item_tool_exec_environment_variables_item_last_updated_by_id import (
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedById,
)
from .agents_search_response_agents_item_tool_exec_environment_variables_item_created_at import (
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAt,
)
from .agents_search_response_agents_item_tool_exec_environment_variables_item_updated_at import (
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAt,
)
from .agents_search_response_agents_item_tool_exec_environment_variables_item_id import (
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemId,
)
from .agents_search_response_agents_item_tool_exec_environment_variables_item_description import (
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemDescription,
)
from .agents_search_response_agents_item_tool_exec_environment_variables_item_organization_id import (
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationId,
)
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItem(UncheckedBaseModel):
    created_by_id: typing.Optional[AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedById] = None
    last_updated_by_id: typing.Optional[
        AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedById
    ] = None
    created_at: typing.Optional[AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAt] = None
    updated_at: typing.Optional[AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAt] = None
    id: typing.Optional[AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemId] = None
    key: str
    value: str
    description: typing.Optional[AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemDescription] = None
    organization_id: typing.Optional[AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationId] = (
        None
    )
    agent_id: str

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
