# This file was auto-generated by Fern from our API Definition.

import typing
from .templates_create_agents_from_template_response_agents_item_memory_blocks_item_metadata_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemMetadataItem,
)

TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemMetadata = typing.Union[
    typing.Optional[str],
    typing.List[typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemMetadataItem]],
    typing.Optional[typing.Any],
]
