# This file was auto-generated by Fern from our API Definition.

import typing
from .templates_create_agents_from_template_response_agents_item_llm_config_put_inner_thoughts_in_kwargs_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigPutInnerThoughtsInKwargsItem,
)

TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigPutInnerThoughtsInKwargs = typing.Union[
    bool,
    typing.Optional[str],
    typing.List[
        typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigPutInnerThoughtsInKwargsItem]
    ],
    typing.Optional[typing.Any],
]
