# This file was auto-generated by Fern from our API Definition.

import typing
from .templates_create_agents_from_template_response_agents_item_llm_config_model_wrapper_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigModelWrapperItem,
)

TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigModelWrapper = typing.Union[
    str,
    typing.Optional[str],
    typing.List[typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigModelWrapperItem]],
    typing.Optional[typing.Any],
]
